@@ -4,6 +4,7 @@ import pytest
 
 from invokelint.lint import (
     bandit,
+    cohesion,
     deep,
     dodgy,
     fast,
@@ -36,6 +37,17 @@ def test_radon(context: Context) -> None:
     check_list_result(list_result, list_command_expected)
 
 
+def test_cohesion(context: Context) -> None:
+    """Function: cohesion() should run appropriate commands."""
+    list_command_expected = [
+        "cohesion --directory invokelint",
+        "cohesion --directory tasks.py",
+        "cohesion --directory tests",
+    ]
+    list_result = cohesion(context)
+    check_list_result(list_result, list_command_expected)
+
+
 def test_bandit(context: Context) -> None:
     check_result(bandit(context), "bandit --recursive --skip B101 tests")
 
